@@ -9,33 +9,38 @@
 #ifndef XDG_DESKTOP_PORTAL_KDE_SCREENSHOT_DIALOG_H
 #define XDG_DESKTOP_PORTAL_KDE_SCREENSHOT_DIALOG_H
 
-#include <QDialog>
+#include "quickdialog.h"
 #include <QFuture>
+#include <QImage>
 
-namespace Ui
-{
-class ScreenshotDialog;
-}
-
-class ScreenshotDialog : public QDialog
+class ScreenshotDialog : public QuickDialog
 {
     Q_OBJECT
 public:
-    explicit ScreenshotDialog(QDialog *parent = nullptr, Qt::WindowFlags flags = {});
-    ~ScreenshotDialog();
+    explicit ScreenshotDialog(QObject *parent = nullptr);
+
+    enum Flags {
+        Borders = 1,
+        Cursor = 1 << 1,
+    };
+    Q_ENUM(Flags)
+    enum ScreenshotType {
+        FullScreen,
+        CurrentScreen,
+        ActiveWindow,
+    };
+    Q_ENUM(ScreenshotType);
 
     QImage image() const;
-
     void takeScreenshotNonInteractive();
 
-private Q_SLOTS:
+public Q_SLOTS:
     void takeScreenshotInteractive();
 
 Q_SIGNALS:
     void failed();
 
 private:
-    Ui::ScreenshotDialog *m_dialog;
     QImage m_image;
 
     int mask();
